@@ -30,6 +30,8 @@ from ._api import (
     set_client_version,
     get_default_settings_variant,
     set_default_settings_variant,
+    get_sender,
+    set_sender,
 
     get_base_url,
     get_rest_url,
@@ -78,6 +80,8 @@ from ._api import (
     download_dependency_package,
     upload_dependency_package,
 
+    upload_addon_zip,
+
     get_bundles,
     create_bundle,
     update_bundle,
@@ -90,6 +94,7 @@ from ._api import (
     get_users,
 
     get_attributes_for_type,
+    get_attributes_fields_for_type,
     get_default_fields_for_type,
 
     get_project_anatomy_preset,
@@ -108,6 +113,11 @@ from ._api import (
     get_addons_project_settings,
     get_addons_settings,
 
+    get_secrets,
+    get_secret,
+    save_secret,
+    delete_secret,
+
     get_project_names,
     get_projects,
     get_project,
@@ -122,6 +132,8 @@ from ._api import (
     get_folders_hierarchy,
 
     get_tasks,
+    get_task_by_id,
+    get_task_by_name,
 
     get_folder_ids_with_products,
     get_product_by_id,
@@ -152,6 +164,7 @@ from ._api import (
     get_workfile_info,
     get_workfile_info_by_id,
 
+    get_thumbnail_by_id,
     get_thumbnail,
     get_folder_thumbnail,
     get_version_thumbnail,
@@ -214,6 +227,8 @@ __all__ = (
     "set_client_version",
     "get_default_settings_variant",
     "set_default_settings_variant",
+    "get_sender",
+    "set_sender",
 
     "get_base_url",
     "get_rest_url",
@@ -262,6 +277,8 @@ __all__ = (
     "download_dependency_package",
     "upload_dependency_package",
 
+    "upload_addon_zip",
+
     "get_bundles",
     "create_bundle",
     "update_bundle",
@@ -274,6 +291,7 @@ __all__ = (
     "get_users",
 
     "get_attributes_for_type",
+    "get_attributes_fields_for_type",
     "get_default_fields_for_type",
 
     "get_project_anatomy_preset",
@@ -291,6 +309,11 @@ __all__ = (
     "get_addons_project_settings",
     "get_addons_settings",
 
+    "get_secrets",
+    "get_secret",
+    "save_secret",
+    "delete_secret",
+
     "get_project_names",
     "get_projects",
     "get_project",
@@ -304,6 +327,8 @@ __all__ = (
     "get_folders",
 
     "get_tasks",
+    "get_task_by_id",
+    "get_task_by_name",
 
     "get_folder_ids_with_products",
     "get_product_by_id",
@@ -334,6 +359,7 @@ __all__ = (
     "get_workfile_info",
     "get_workfile_info_by_id",
 
+    "get_thumbnail_by_id",
     "get_thumbnail",
     "get_folder_thumbnail",
     "get_version_thumbnail",
