@@ -25,12 +25,29 @@ class GlobalServerAPI(ServerAPI):
     but that can be filled afterwards with calling 'login' method.
     """
 
-    def __init__(self, site_id=None, client_version=None):
+    def __init__(
+        self,
+        site_id=None,
+        client_version=None,
+        default_settings_variant=None,
+        ssl_verify=None,
+        cert=None,
+    ):
         url = self.get_url()
         token = self.get_token()
 
-        super(GlobalServerAPI, self).__init__(url, token, site_id, client_version)
-
+        super(GlobalServerAPI, self).__init__(
+            url,
+            token,
+            site_id,
+            client_version,
+            default_settings_variant,
+            ssl_verify,
+            cert,
+            # We want to make sure that server and api key validation
+            #   happens all the time in 'GlobalServerAPI'.
+            create_session=False,
+        )
         self.validate_server_availability()
         self.create_session()
 
@@ -129,17 +146,6 @@ class ServiceContext:
     addon_version = None
     service_name = None
 
-    @staticmethod
-    def get_value_from_envs(env_keys, value=None):
-        if value:
-            return value
-
-        for env_key in env_keys:
-            value = os.environ.get(env_key)
-            if value:
-                break
-        return value
-
     @classmethod
     def init_service(
         cls,
@@ -150,14 +156,8 @@ class ServiceContext:
         service_name=None,
         connect=True
     ):
-        token = cls.get_value_from_envs(
-            ("AY_API_KEY", "AYON_API_KEY"),
-            token
-        )
-        server_url = cls.get_value_from_envs(
-            ("AY_SERVER_URL", "AYON_SERVER_URL"),
-            server_url
-        )
+        token = token or os.environ.get("AYON_API_KEY")
+        server_url = server_url or os.environ.get("AYON_SERVER_URL")
         if not server_url:
             raise FailedServiceInit("URL to server is not set")
 
@@ -166,18 +166,9 @@ class ServiceContext:
                 "Token to server {} is not set".format(server_url)
             )
 
-        addon_name = cls.get_value_from_envs(
-            ("AY_ADDON_NAME", "AYON_ADDON_NAME"),
-            addon_name
-        )
-        addon_version = cls.get_value_from_envs(
-            ("AY_ADDON_VERSION", "AYON_ADDON_VERSION"),
-            addon_version
-        )
-        service_name = cls.get_value_from_envs(
-            ("AY_SERVICE_NAME", "AYON_SERVICE_NAME"),
-            service_name
-        )
+        addon_name = addon_name or os.environ.get("AYON_ADDON_NAME")
+        addon_version = addon_version or os.environ.get("AYON_ADDON_VERSION")
+        service_name = service_name or os.environ.get("AYON_SERVICE_NAME")
 
         cls.token = token
         cls.server_url = server_url
@@ -401,6 +392,28 @@ def set_default_settings_variant(variant):
     return con.set_default_settings_variant(variant)
 
 
+def get_sender():
+    """Sender used to send requests.
+
+    Returns:
+        Union[str, None]: Sender name or None.
+    """
+
+    con = get_server_api_connection()
+    return con.get_sender()
+
+
+def set_sender(sender):
+    """Change sender used for requests.
+
+    Args:
+        sender (Union[str, None]): Sender name or None.
+    """
+
+    con = get_server_api_connection()
+    return con.set_sender(sender)
+
+
 def get_base_url():
     con = get_server_api_connection()
     return con.get_base_url()
@@ -618,6 +631,11 @@ def delete_dependency_package(*args, **kwargs):
     return con.delete_dependency_package(*args, **kwargs)
 
 
+def upload_addon_zip(*args, **kwargs):
+    con = get_server_api_connection()
+    return con.upload_addon_zip(*args, **kwargs)
+
+
 def get_project_anatomy_presets(*args, **kwargs):
     con = get_server_api_connection()
     return con.get_project_anatomy_presets(*args, **kwargs)
@@ -708,6 +726,26 @@ def get_addons_settings(*args, **kwargs):
     return con.get_addons_settings(*args, **kwargs)
 
 
+def get_secrets(*args, **kwargs):
+    con = get_server_api_connection()
+    return con.get_secrets(*args, **kwargs)
+
+
+def get_secret(*args, **kwargs):
+    con = get_server_api_connection()
+    return con.delete_secret(*args, **kwargs)
+
+
+def save_secret(*args, **kwargs):
+    con = get_server_api_connection()
+    return con.delete_secret(*args, **kwargs)
+
+
+def delete_secret(*args, **kwargs):
+    con = get_server_api_connection()
+    return con.delete_secret(*args, **kwargs)
+
+
 def get_project_names(*args, **kwargs):
     con = get_server_api_connection()
     return con.get_project_names(*args, **kwargs)
@@ -738,6 +776,16 @@ def get_tasks(*args, **kwargs):
     return con.get_tasks(*args, **kwargs)
 
 
+def get_task_by_id(*args, **kwargs):
+    con = get_server_api_connection()
+    return con.get_task_by_id(*args, **kwargs)
+
+
+def get_task_by_name(*args, **kwargs):
+    con = get_server_api_connection()
+    return con.get_task_by_name(*args, **kwargs)
+
+
 def get_folder_by_id(*args, **kwargs):
     con = get_server_api_connection()
     return con.get_folder_by_id(*args, **kwargs)
@@ -908,6 +956,11 @@ def delete_project(project_name):
     return con.delete_project(project_name)
 
 
+def get_thumbnail_by_id(project_name, thumbnail_id):
+    con = get_server_api_connection()
+    con.get_thumbnail_by_id(project_name, thumbnail_id)
+
+
 def get_thumbnail(project_name, entity_type, entity_id, thumbnail_id=None):
     con = get_server_api_connection()
     con.get_thumbnail(project_name, entity_type, entity_id, thumbnail_id)
@@ -938,6 +991,11 @@ def update_thumbnail(project_name, thumbnail_id, src_filepath):
     return con.update_thumbnail(project_name, thumbnail_id, src_filepath)
 
 
+def get_attributes_fields_for_type(entity_type):
+    con = get_server_api_connection()
+    return con.get_attributes_fields_for_type(entity_type)
+
+
 def get_default_fields_for_type(entity_type):
     con = get_server_api_connection()
     return con.get_default_fields_for_type(entity_type)
